# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/corporate_actions/v1/splits.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/corporate_actions/v1/splits.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<systemathics/apis/services/corporate_actions/v1/splits.proto\x12/systemathics.apis.services.corporate_actions.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xb2\x01\n\rSplitsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"\\\n\x0eSplitsResponse\x12J\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.corporate_actions.v1.SplitR\x04\x64\x61ta\"\x82\x01\n\x05Split\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x1d\n\nnew_shares\x18\x02 \x01(\x01R\tnewShares\x12\x1d\n\nold_shares\x18\x03 \x01(\x01R\toldShares\x12\x14\n\x05score\x18\x04 \x01(\x01R\x05score2\xc1\x01\n\rSplitsService\x12\xaf\x01\n\x06Splits\x12>.systemathics.apis.services.corporate_actions.v1.SplitsRequest\x1a?.systemathics.apis.services.corporate_actions.v1.SplitsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/corporate-actions/splitsB\x9f\x02\n3com.systemathics.apis.services.corporate_actions.v1B\x0bSplitsProtoP\x01\xa2\x02\x04SASC\xaa\x02.Systemathics.Apis.Services.CorporateActions.V1\xca\x02.Systemathics\\Apis\\Services\\CorporateActions\\V1\xe2\x02:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\xea\x02\x32Systemathics::Apis::Services::CorporateActions::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.corporate_actions.v1.splits_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.systemathics.apis.services.corporate_actions.v1B\013SplitsProtoP\001\242\002\004SASC\252\002.Systemathics.Apis.Services.CorporateActions.V1\312\002.Systemathics\\Apis\\Services\\CorporateActions\\V1\342\002:Systemathics\\Apis\\Services\\CorporateActions\\V1\\GPBMetadata\352\0022Systemathics::Apis::Services::CorporateActions::V1'
  _globals['_SPLITSSERVICE'].methods_by_name['Splits']._loaded_options = None
  _globals['_SPLITSSERVICE'].methods_by_name['Splits']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/corporate-actions/splits'
  _globals['_SPLITSREQUEST']._serialized_start=273
  _globals['_SPLITSREQUEST']._serialized_end=451
  _globals['_SPLITSRESPONSE']._serialized_start=453
  _globals['_SPLITSRESPONSE']._serialized_end=545
  _globals['_SPLIT']._serialized_start=548
  _globals['_SPLIT']._serialized_end=678
  _globals['_SPLITSSERVICE']._serialized_start=681
  _globals['_SPLITSSERVICE']._serialized_end=874
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import condition_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_condition__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHsystemathics/apis/services/tick_analytics/v1/tick_trade_conditions.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x30systemathics/apis/type/shared/v1/condition.proto\"\xd8\x02\n\x1aTickTradeConditionsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12\x35\n\x08sampling\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08sampling\x12\x31\n\x06period\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\"\xaf\x02\n\x1bTickTradeConditionsResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x16\n\x06volume\x18\x02 \x01(\x03R\x06volume\x12\x14\n\x05\x63ount\x18\x03 \x01(\x03R\x05\x63ount\x12M\n\x0b\x64\x65scription\x18\x04 \x03(\x0b\x32+.systemathics.apis.type.shared.v1.ConditionR\x0b\x64\x65scription\x12X\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x44.systemathics.apis.services.tick_analytics.v1.TickTradeConditionDataR\x04\x64\x61ta\"\xa9\x01\n\x16TickTradeConditionData\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x14\n\x05\x63ount\x18\x02 \x01(\x03R\x05\x63ount\x12\x1e\n\npercentage\x18\x03 \x01(\x01R\npercentage\x12\x16\n\x06volume\x18\x04 \x01(\x03R\x06volume\x12+\n\x11volume_percentage\x18\x05 \x01(\x01R\x10volumePercentage2\xf8\x01\n\x1aTickTradeConditionsService\x12\xd9\x01\n\x13TickTradeConditions\x12H.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsRequest\x1aI.systemathics.apis.services.tick_analytics.v1.TickTradeConditionsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/tick-analytics/trade-conditions0\x01\x42\x9d\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x18TickTradeConditionsProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_trade_conditions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\030TickTradeConditionsProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKTRADECONDITIONSSERVICE'].methods_by_name['TickTradeConditions']._loaded_options = None
  _globals['_TICKTRADECONDITIONSSERVICE'].methods_by_name['TickTradeConditions']._serialized_options = b'\202\323\344\223\002%\022#/v1/tick-analytics/trade-conditions'
  _globals['_TICKTRADECONDITIONSREQUEST']._serialized_start=371
  _globals['_TICKTRADECONDITIONSREQUEST']._serialized_end=715
  _globals['_TICKTRADECONDITIONSRESPONSE']._serialized_start=718
  _globals['_TICKTRADECONDITIONSRESPONSE']._serialized_end=1021
  _globals['_TICKTRADECONDITIONDATA']._serialized_start=1024
  _globals['_TICKTRADECONDITIONDATA']._serialized_end=1193
  _globals['_TICKTRADECONDITIONSSERVICE']._serialized_start=1196
  _globals['_TICKTRADECONDITIONSSERVICE']._serialized_end=1444
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/private/v1/memos.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/private/v1/memos.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/private/v1/memos.proto\x12%systemathics.apis.services.private.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\"\xf2\x01\n\x0cMemosRequest\x12#\n\rsearch_string\x18\x01 \x01(\tR\x0csearchString\x12W\n\x0bsearch_type\x18\x02 \x01(\x0e\x32\x36.systemathics.apis.services.private.v1.MemosSearchTypeR\nsearchType\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"h\n\rMemosResponse\x12<\n\x05memos\x18\x01 \x03(\x0b\x32&.systemathics.apis.type.shared.v1.MemoR\x05memos\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore*\x80\x01\n\x0fMemosSearchType\x12!\n\x1dMEMOS_SEARCH_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cMEMOS_SEARCH_TYPE_SUB_STRING\x10\x01\x12(\n$MEMOS_SEARCH_TYPE_REGULAR_EXPRESSION\x10\x02\x32\x96\x01\n\x0cMemosService\x12\x85\x01\n\x05Memos\x12\x33.systemathics.apis.services.private.v1.MemosRequest\x1a\x34.systemathics.apis.services.private.v1.MemosResponse\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/memosB\xf2\x01\n)com.systemathics.apis.services.private.v1B\nMemosProtoP\x01\xa2\x02\x04SASP\xaa\x02%Systemathics.Apis.Services.Private.V1\xca\x02&Systemathics\\Apis\\Services\\Private_\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Private::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.private.v1.memos_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.private.v1B\nMemosProtoP\001\242\002\004SASP\252\002%Systemathics.Apis.Services.Private.V1\312\002&Systemathics\\Apis\\Services\\Private_\\V1\342\0022Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Private::V1'
  _globals['_MEMOSSERVICE'].methods_by_name['Memos']._loaded_options = None
  _globals['_MEMOSSERVICE'].methods_by_name['Memos']._serialized_options = b'\202\323\344\223\002\013\022\t/v1/memos'
  _globals['_MEMOSSEARCHTYPE']._serialized_start=551
  _globals['_MEMOSSEARCHTYPE']._serialized_end=679
  _globals['_MEMOSREQUEST']._serialized_start=200
  _globals['_MEMOSREQUEST']._serialized_end=442
  _globals['_MEMOSRESPONSE']._serialized_start=444
  _globals['_MEMOSRESPONSE']._serialized_end=548
  _globals['_MEMOSSERVICE']._serialized_start=682
  _globals['_MEMOSSERVICE']._serialized_end=832
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v1/keys.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v1/keys.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+systemathics/apis/type/shared/v1/keys.proto\x12 systemathics.apis.type.shared.v1\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"i\n\x03Key\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x14\n\x05value\x18\x02 \x01(\rR\x05value\"E\n\x04Keys\x12=\n\x06values\x18\x01 \x03(\x0b\x32%.systemathics.apis.type.shared.v1.KeyR\x06valuesB\xd6\x01\n$com.systemathics.apis.type.shared.v1B\tKeysProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.keys_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\tKeysProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_KEY']._serialized_start=132
  _globals['_KEY']._serialized_end=237
  _globals['_KEYS']._serialized_start=239
  _globals['_KEYS']._serialized_end=308
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v1/tick_spread.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v1/tick_spread.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/tick_analytics/v1/tick_spread.proto\x12,systemathics.apis.services.tick_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xe4\x02\n\x11TickSpreadRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\x12?\n\x0cmin_accepted\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0bminAccepted\x12?\n\x0cmax_accepted\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0bmaxAccepted\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x05 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x06 \x03(\tR\x06reject\"\xaa\x02\n\x12TickSpreadResponse\x12H\n\x03\x62id\x18\x01 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideDataR\x03\x62id\x12H\n\x03\x61sk\x18\x02 \x01(\x0b\x32\x36.systemathics.apis.services.tick_analytics.v1.SideDataR\x03\x61sk\x12\x12\n\x04last\x18\x03 \x01(\x01R\x04last\x12\x18\n\x07\x61verage\x18\x04 \x01(\x01R\x07\x61verage\x12\x10\n\x03min\x18\x05 \x01(\x01R\x03min\x12\x10\n\x03max\x18\x06 \x01(\x01R\x03max\x12\x14\n\x05\x63ount\x18\x07 \x01(\x03R\x05\x63ount\x12\x18\n\x07skipped\x18\x08 \x01(\x03R\x07skipped\"\x9e\x01\n\x08SideData\x12\x12\n\x04last\x18\x01 \x01(\x01R\x04last\x12\x18\n\x07\x61verage\x18\x02 \x01(\x01R\x07\x61verage\x12\x12\n\x04vwap\x18\x03 \x01(\x01R\x04vwap\x12\x10\n\x03min\x18\x04 \x01(\x01R\x03min\x12\x10\n\x03max\x18\x05 \x01(\x01R\x03max\x12\x16\n\x06volume\x18\x06 \x01(\x03R\x06volume\x12\x14\n\x05\x63ount\x18\x07 \x01(\x03R\x05\x63ount2\xca\x01\n\x11TickSpreadService\x12\xb4\x01\n\nTickSpread\x12?.systemathics.apis.services.tick_analytics.v1.TickSpreadRequest\x1a@.systemathics.apis.services.tick_analytics.v1.TickSpreadResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/tick-analytics/spread0\x01\x42\x94\x02\n0com.systemathics.apis.services.tick_analytics.v1B\x0fTickSpreadProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V1\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V1\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v1.tick_spread_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v1B\017TickSpreadProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V1\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V1\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V1\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V1'
  _globals['_TICKSPREADSERVICE'].methods_by_name['TickSpread']._loaded_options = None
  _globals['_TICKSPREADSERVICE'].methods_by_name['TickSpread']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/tick-analytics/spread'
  _globals['_TICKSPREADREQUEST']._serialized_start=278
  _globals['_TICKSPREADREQUEST']._serialized_end=634
  _globals['_TICKSPREADRESPONSE']._serialized_start=637
  _globals['_TICKSPREADRESPONSE']._serialized_end=935
  _globals['_SIDEDATA']._serialized_start=938
  _globals['_SIDEDATA']._serialized_end=1096
  _globals['_TICKSPREADSERVICE']._serialized_start=1099
  _globals['_TICKSPREADSERVICE']._serialized_end=1301
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_identifier__pb2
from systemathics.apis.type.shared.v2 import decimals_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_decimals__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?systemathics/apis/services/tick_analytics/v2/tick_vwap_hp.proto\x12,systemathics.apis.services.tick_analytics.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v2/constraints.proto\x1a\x31systemathics/apis/type/shared/v2/identifier.proto\x1a/systemathics/apis/type/shared/v2/decimals.proto\"\xb9\x03\n\x11HpTickVwapRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v2.IdentifierR\nidentifier\x12O\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v2.ConstraintsR\x0b\x63onstraints\x12\x31\n\x06period\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06period\x12\x31\n\x06offset\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06offset\x12\x1e\n\nadjustment\x18\x05 \x01(\x08R\nadjustment\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x06 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x07 \x03(\tR\x06reject\x12O\n\x15\x62uffering_window_size\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x13\x62ufferingWindowSize\"\x90\x03\n\x12HpTickVwapResponse\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x43\n\x04vwap\x18\x02 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalR\x04vwap\x12\x45\n\x05trade\x18\x03 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalR\x05trade\x12I\n\x06volume\x18\x04 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v2.UnsignedDecimalR\x06volume\x12\x14\n\x05\x63ount\x18\x05 \x01(\x04R\x05\x63ount\x12R\n\x16total_processed_frames\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt64ValueR\x14totalProcessedFrames2\xcb\x01\n\x11HpTickVwapService\x12\xb5\x01\n\nHpTickVwap\x12?.systemathics.apis.services.tick_analytics.v2.HpTickVwapRequest\x1a@.systemathics.apis.services.tick_analytics.v2.HpTickVwapResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v2/tick-analytics/vwap-hp0\x01\x42\x94\x02\n0com.systemathics.apis.services.tick_analytics.v2B\x0fTickVwapHpProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V2\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V2\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v2.tick_vwap_hp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v2B\017TickVwapHpProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V2\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V2\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V2'
  _globals['_HPTICKVWAPSERVICE'].methods_by_name['HpTickVwap']._loaded_options = None
  _globals['_HPTICKVWAPSERVICE'].methods_by_name['HpTickVwap']._serialized_options = b'\202\323\344\223\002\034\022\032/v2/tick-analytics/vwap-hp'
  _globals['_HPTICKVWAPREQUEST']._serialized_start=393
  _globals['_HPTICKVWAPREQUEST']._serialized_end=834
  _globals['_HPTICKVWAPRESPONSE']._serialized_start=837
  _globals['_HPTICKVWAPRESPONSE']._serialized_end=1237
  _globals['_HPTICKVWAPSERVICE']._serialized_start=1240
  _globals['_HPTICKVWAPSERVICE']._serialized_end=1443
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/v2/artifacts.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/v2/artifacts.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-systemathics/apis/services/v2/artifacts.proto\x12\x1dsystemathics.apis.services.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf2\x01\n\x10\x41rtifactsRequest\x12#\n\rsearch_string\x18\x01 \x01(\tR\x0csearchString\x12S\n\x0bsearch_type\x18\x02 \x01(\x0e\x32\x32.systemathics.apis.services.v2.ArtifactsSearchTypeR\nsearchType\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"u\n\x11\x41rtifactsResponse\x12\x45\n\tartifacts\x18\x01 \x03(\x0b\x32\'.systemathics.apis.services.v2.ArtifactR\tartifacts\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore\"\xc3\x03\n\x08\x41rtifact\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04size\x18\x02 \x01(\x03R\x04size\x12?\n\rlast_modified\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0clastModified\x12\x32\n\x05xxh64\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05xxh64\x12K\n\x13normalization_start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12normalizationStart\x12G\n\x11normalization_end\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10normalizationEnd\x12\x43\n\x0fpromotion_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0epromotionStart\x12?\n\rpromotion_end\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cpromotionEnd*\x90\x01\n\x13\x41rtifactsSearchType\x12%\n!ARTIFACTS_SEARCH_TYPE_UNSPECIFIED\x10\x00\x12$\n ARTIFACTS_SEARCH_TYPE_SUB_STRING\x10\x01\x12,\n(ARTIFACTS_SEARCH_TYPE_REGULAR_EXPRESSION\x10\x02\x32\x82\x01\n\x10\x41rtifactsService\x12n\n\tArtifacts\x12/.systemathics.apis.services.v2.ArtifactsRequest\x1a\x30.systemathics.apis.services.v2.ArtifactsResponseB\xca\x01\n!com.systemathics.apis.services.v2B\x0e\x41rtifactsProtoP\x01\xa2\x02\x03SAS\xaa\x02\x1dSystemathics.Apis.Services.V2\xca\x02\x1dSystemathics\\Apis\\Services\\V2\xe2\x02)Systemathics\\Apis\\Services\\V2\\GPBMetadata\xea\x02 Systemathics::Apis::Services::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.v2.artifacts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.systemathics.apis.services.v2B\016ArtifactsProtoP\001\242\002\003SAS\252\002\035Systemathics.Apis.Services.V2\312\002\035Systemathics\\Apis\\Services\\V2\342\002)Systemathics\\Apis\\Services\\V2\\GPBMetadata\352\002 Systemathics::Apis::Services::V2'
  _globals['_ARTIFACTSSEARCHTYPE']._serialized_start=964
  _globals['_ARTIFACTSSEARCHTYPE']._serialized_end=1108
  _globals['_ARTIFACTSREQUEST']._serialized_start=146
  _globals['_ARTIFACTSREQUEST']._serialized_end=388
  _globals['_ARTIFACTSRESPONSE']._serialized_start=390
  _globals['_ARTIFACTSRESPONSE']._serialized_end=507
  _globals['_ARTIFACT']._serialized_start=510
  _globals['_ARTIFACT']._serialized_end=961
  _globals['_ARTIFACTSSERVICE']._serialized_start=1111
  _globals['_ARTIFACTSSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v1/constraints.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v1/constraints.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from google.type import dayofweek_pb2 as google_dot_type_dot_dayofweek__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import time_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_time__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2systemathics/apis/type/shared/v1/constraints.proto\x12 systemathics.apis.type.shared.v1\x1a\x16google/type/date.proto\x1a\x1bgoogle/type/dayofweek.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a\x34systemathics/apis/type/shared/v1/time_interval.proto\"\xb2\x02\n\x0b\x43onstraints\x12U\n\x0e\x64\x61te_intervals\x18\x01 \x03(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\rdateIntervals\x12U\n\x0etime_intervals\x18\x02 \x03(\x0b\x32..systemathics.apis.type.shared.v1.TimeIntervalR\rtimeIntervals\x12\x38\n\x0e\x65xcluded_dates\x18\x03 \x03(\x0b\x32\x11.google.type.DateR\rexcludedDates\x12;\n\rexcluded_days\x18\x04 \x03(\x0e\x32\x16.google.type.DayOfWeekR\x0c\x65xcludedDaysB\xdd\x01\n$com.systemathics.apis.type.shared.v1B\x10\x43onstraintsProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.constraints_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\020ConstraintsProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_CONSTRAINTS']._serialized_start=250
  _globals['_CONSTRAINTS']._serialized_end=556
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/topology/v2/topologies.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/topology/v2/topologies.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v2 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_memo__pb2
from systemathics.apis.type.shared.v2 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7systemathics/apis/services/topology/v2/topologies.proto\x12&systemathics.apis.services.topology.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a+systemathics/apis/type/shared/v2/memo.proto\x1a,systemathics/apis/type/shared/v2/level.proto\"\x94\x02\n\x11TopologiesRequest\x12:\n\x04memo\x18\x01 \x01(\x0b\x32&.systemathics.apis.type.shared.v2.MemoR\x04memo\x12]\n\x0bgranularity\x18\x02 \x01(\x0e\x32;.systemathics.apis.services.topology.v2.TopologyGranularityR\x0bgranularity\x12\x31\n\x05start\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\"~\n\rTopologyEntry\x12\'\n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x05\x62\x65gin\x12#\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x03\x65nd\x12\x1f\n\x0bticks_count\x18\x03 \x01(\x04R\nticksCount\"\x80\x01\n\x12TopologiesResponse\x12O\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v2.TopologyEntryR\x07\x65ntries\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\xb1\x01\n\x11TopologiesService\x12\x9b\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v2.TopologiesRequest\x1a:.systemathics.apis.services.topology.v2.TopologiesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v2/topologiesB\xfa\x01\n*com.systemathics.apis.services.topology.v2B\x0fTopologiesProtoP\x01\xa2\x02\x04SAST\xaa\x02&Systemathics.Apis.Services.Topology.V2\xca\x02&Systemathics\\Apis\\Services\\Topology\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Topology\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Topology::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.topology.v2.topologies_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.topology.v2B\017TopologiesProtoP\001\242\002\004SAST\252\002&Systemathics.Apis.Services.Topology.V2\312\002&Systemathics\\Apis\\Services\\Topology\\V2\342\0022Systemathics\\Apis\\Services\\Topology\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Topology::V2'
  _globals['_TOPOLOGIESSERVICE'].methods_by_name['Topologies']._loaded_options = None
  _globals['_TOPOLOGIESSERVICE'].methods_by_name['Topologies']._serialized_options = b'\202\323\344\223\002\020\022\016/v2/topologies'
  _globals['_TOPOLOGYGRANULARITY']._serialized_start=815
  _globals['_TOPOLOGYGRANULARITY']._serialized_end=1041
  _globals['_TOPOLOGIESREQUEST']._serialized_start=277
  _globals['_TOPOLOGIESREQUEST']._serialized_end=553
  _globals['_TOPOLOGYENTRY']._serialized_start=555
  _globals['_TOPOLOGYENTRY']._serialized_end=681
  _globals['_TOPOLOGIESRESPONSE']._serialized_start=684
  _globals['_TOPOLOGIESRESPONSE']._serialized_end=812
  _globals['_TOPOLOGIESSERVICE']._serialized_start=1044
  _globals['_TOPOLOGIESSERVICE']._serialized_end=1221
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick/v2/tick_raw.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick/v2/tick_raw.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_identifier__pb2
from systemathics.apis.type.shared.v2 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_level__pb2
from systemathics.apis.type.shared.v2 import keys_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_keys__pb2
from systemathics.apis.type.shared.v2 import raw_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_raw__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1systemathics/apis/services/tick/v2/tick_raw.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x32systemathics/apis/type/shared/v2/constraints.proto\x1a\x31systemathics/apis/type/shared/v2/identifier.proto\x1a,systemathics/apis/type/shared/v2/level.proto\x1a+systemathics/apis/type/shared/v2/keys.proto\x1a*systemathics/apis/type/shared/v2/raw.proto\"\xc1\x02\n\x0eTickRawRequest\x12N\n\x0bidentifiers\x18\x01 \x03(\x0b\x32,.systemathics.apis.type.shared.v2.IdentifierR\x0bidentifiers\x12=\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v2.LevelR\x05level\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v2.ConstraintsR\x0b\x63onstraints\x12O\n\x15\x62uffering_window_size\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x13\x62ufferingWindowSize\"\x9b\x01\n\x0fTickRawResponse\x12\x39\n\x03raw\x18\x01 \x01(\x0b\x32%.systemathics.apis.type.shared.v2.RawH\x00R\x03raw\x12\x42\n\x07mapping\x18\x02 \x01(\x0b\x32&.systemathics.apis.type.shared.v2.KeysH\x00R\x07mappingB\t\n\x07payload2\x9d\x01\n\x0eTickRawService\x12\x8a\x01\n\x07TickRaw\x12\x32.systemathics.apis.services.tick.v2.TickRawRequest\x1a\x33.systemathics.apis.services.tick.v2.TickRawResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v2/tick/raw0\x01\x42\xe3\x01\n&com.systemathics.apis.services.tick.v2B\x0cTickRawProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.tick_raw_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\014TickRawProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._loaded_options = None
  _globals['_TICKRAWSERVICE'].methods_by_name['TickRaw']._serialized_options = b'\202\323\344\223\002\016\022\014/v2/tick/raw'
  _globals['_TICKRAWREQUEST']._serialized_start=390
  _globals['_TICKRAWREQUEST']._serialized_end=711
  _globals['_TICKRAWRESPONSE']._serialized_start=714
  _globals['_TICKRAWRESPONSE']._serialized_end=869
  _globals['_TICKRAWSERVICE']._serialized_start=872
  _globals['_TICKRAWSERVICE']._serialized_end=1029
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/tick_analytics/v2/tick_priips_batch.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/tick_analytics/v2/tick_priips_batch.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from systemathics.apis.services.tick_analytics.v2 import tick_priips_pb2 as systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__priips__pb2
from systemathics.apis.type.shared.v2 import price_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_price__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/tick_analytics/v2/tick_priips_batch.proto\x12,systemathics.apis.services.tick_analytics.v2\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a>systemathics/apis/services/tick_analytics/v2/tick_priips.proto\x1a,systemathics/apis/type/shared/v2/price.proto\"\xd7\x02\n\x16TickPriipsBatchRequest\x12\x15\n\x06\x63sv_gz\x18\x01 \x01(\x0cR\x05\x63svGz\x12=\n\x05\x66ield\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v2.PriceR\x05\x66ield\x12\x33\n\x07latency\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x07latency\x12\x16\n\x06\x61\x63\x63\x65pt\x18\x04 \x03(\tR\x06\x61\x63\x63\x65pt\x12\x16\n\x06reject\x18\x05 \x03(\tR\x06reject\x12\x18\n\x07metrics\x18\x06 \x01(\x08R\x07metrics\x12K\n\"use_reverse_iteration_optimization\x18\x07 \x01(\x08R\x1fuseReverseIterationOptimization\x12\x1b\n\ttime_zone\x18\x08 \x01(\x0cR\x08timeZone\"T\n\x17TickPriipsBatchResponse\x12\x15\n\x06\x63sv_gz\x18\x01 \x01(\x0cR\x05\x63svGz\x12\"\n\rerrors_csv_gz\x18\x02 \x01(\x0cR\x0b\x65rrorsCsvGz2\xe2\x01\n\x16TickPriipsBatchService\x12\xc7\x01\n\x0fTickPriipsBatch\x12\x44.systemathics.apis.services.tick_analytics.v2.TickPriipsBatchRequest\x1a\x45.systemathics.apis.services.tick_analytics.v2.TickPriipsBatchResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v2/tick-analytics/priips-batchB\x99\x02\n0com.systemathics.apis.services.tick_analytics.v2B\x14TickPriipsBatchProtoP\x01\xa2\x02\x04SAST\xaa\x02+Systemathics.Apis.Services.TickAnalytics.V2\xca\x02+Systemathics\\Apis\\Services\\TickAnalytics\\V2\xe2\x02\x37Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\xea\x02/Systemathics::Apis::Services::TickAnalytics::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick_analytics.v2.tick_priips_batch_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.tick_analytics.v2B\024TickPriipsBatchProtoP\001\242\002\004SAST\252\002+Systemathics.Apis.Services.TickAnalytics.V2\312\002+Systemathics\\Apis\\Services\\TickAnalytics\\V2\342\0027Systemathics\\Apis\\Services\\TickAnalytics\\V2\\GPBMetadata\352\002/Systemathics::Apis::Services::TickAnalytics::V2'
  _globals['_TICKPRIIPSBATCHSERVICE'].methods_by_name['TickPriipsBatch']._loaded_options = None
  _globals['_TICKPRIIPSBATCHSERVICE'].methods_by_name['TickPriipsBatch']._serialized_options = b'\202\323\344\223\002!\022\037/v2/tick-analytics/priips-batch'
  _globals['_TICKPRIIPSBATCHREQUEST']._serialized_start=291
  _globals['_TICKPRIIPSBATCHREQUEST']._serialized_end=634
  _globals['_TICKPRIIPSBATCHRESPONSE']._serialized_start=636
  _globals['_TICKPRIIPSBATCHRESPONSE']._serialized_end=720
  _globals['_TICKPRIIPSBATCHSERVICE']._serialized_start=723
  _globals['_TICKPRIIPSBATCHSERVICE']._serialized_end=949
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v1/limit.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v1/limit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v1 import quote_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_quote__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/limit.proto\x12 systemathics.apis.type.shared.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a,systemathics/apis/type/shared/v1/quote.proto\"\xc3\x01\n\x05Limit\x12\x32\n\x05price\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12/\n\x04size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x04size\x12\x14\n\x05\x64\x65pth\x18\x03 \x01(\rR\x05\x64\x65pth\x12?\n\x06quotes\x18\x04 \x03(\x0b\x32\'.systemathics.apis.type.shared.v1.QuoteR\x06quotesB\xd7\x01\n$com.systemathics.apis.type.shared.v1B\nLimitProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\nLimitProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_LIMIT']._serialized_start=161
  _globals['_LIMIT']._serialized_end=356
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/daily/v1/daily_implied_volatility.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/daily/v1/daily_implied_volatility.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBsystemathics/apis/services/daily/v1/daily_implied_volatility.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xc4\x01\n\x1f\x44\x61ilyImpliedVolatilitiesRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"s\n DailyImpliedVolatilitiesResponse\x12O\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily.v1.DailyImpliedVolatilityR\x04\x64\x61ta\"k\n\x16\x44\x61ilyImpliedVolatility\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x14\n\x05score\x18\x03 \x01(\x01R\x05score2\xf2\x01\n\x1f\x44\x61ilyImpliedVolatilitiesService\x12\xce\x01\n\x18\x44\x61ilyImpliedVolatilities\x12\x44.systemathics.apis.services.daily.v1.DailyImpliedVolatilitiesRequest\x1a\x45.systemathics.apis.services.daily.v1.DailyImpliedVolatilitiesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/daily/impliedvolatilitiesB\xf7\x01\n\'com.systemathics.apis.services.daily.v1B\x1b\x44\x61ilyImpliedVolatilityProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_implied_volatility_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\033DailyImpliedVolatilityProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['DailyImpliedVolatilities']._loaded_options = None
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['DailyImpliedVolatilities']._serialized_options = b'\202\323\344\223\002\037\022\035/v1/daily/impliedvolatilities'
  _globals['_DAILYIMPLIEDVOLATILITIESREQUEST']._serialized_start=267
  _globals['_DAILYIMPLIEDVOLATILITIESREQUEST']._serialized_end=463
  _globals['_DAILYIMPLIEDVOLATILITIESRESPONSE']._serialized_start=465
  _globals['_DAILYIMPLIEDVOLATILITIESRESPONSE']._serialized_end=580
  _globals['_DAILYIMPLIEDVOLATILITY']._serialized_start=582
  _globals['_DAILYIMPLIEDVOLATILITY']._serialized_end=689
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE']._serialized_start=692
  _globals['_DAILYIMPLIEDVOLATILITIESSERVICE']._serialized_end=934
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/intraday/v1/intraday_implied_volatility.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/intraday/v1/intraday_implied_volatility.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHsystemathics/apis/services/intraday/v1/intraday_implied_volatility.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x8f\x02\n\"IntradayImpliedVolatilitiesRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"|\n#IntradayImpliedVolatilitiesResponse\x12U\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x41.systemathics.apis.services.intraday.v1.IntradayImpliedVolatilityR\x04\x64\x61ta\"\x82\x01\n\x19IntradayImpliedVolatility\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x14\n\x05score\x18\x03 \x01(\x01R\x05score2\x87\x02\n\"IntradayImpliedVolatilitiesService\x12\xe0\x01\n\x1bIntradayImpliedVolatilities\x12J.systemathics.apis.services.intraday.v1.IntradayImpliedVolatilitiesRequest\x1aK.systemathics.apis.services.intraday.v1.IntradayImpliedVolatilitiesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/intraday/impliedvolatilitiesB\x89\x02\n*com.systemathics.apis.services.intraday.v1B\x1eIntradayImpliedVolatilityProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V1\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v1.intraday_implied_volatility_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v1B\036IntradayImpliedVolatilityProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V1\312\002&Systemathics\\Apis\\Services\\Intraday\\V1\342\0022Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V1'
  _globals['_INTRADAYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['IntradayImpliedVolatilities']._loaded_options = None
  _globals['_INTRADAYIMPLIEDVOLATILITIESSERVICE'].methods_by_name['IntradayImpliedVolatilities']._serialized_options = b'\202\323\344\223\002\"\022 /v1/intraday/impliedvolatilities'
  _globals['_INTRADAYIMPLIEDVOLATILITIESREQUEST']._serialized_start=334
  _globals['_INTRADAYIMPLIEDVOLATILITIESREQUEST']._serialized_end=605
  _globals['_INTRADAYIMPLIEDVOLATILITIESRESPONSE']._serialized_start=607
  _globals['_INTRADAYIMPLIEDVOLATILITIESRESPONSE']._serialized_end=731
  _globals['_INTRADAYIMPLIEDVOLATILITY']._serialized_start=734
  _globals['_INTRADAYIMPLIEDVOLATILITY']._serialized_end=864
  _globals['_INTRADAYIMPLIEDVOLATILITIESSERVICE']._serialized_start=867
  _globals['_INTRADAYIMPLIEDVOLATILITIESSERVICE']._serialized_end=1130
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/static_data/v1/static_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/static_data/v1/static_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xc4\x11\n\x11StaticDataRequest\x12S\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetTypeR\tassetType\x12\x31\n\x05start\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05start\x12\x31\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x05\x63ount\x12:\n\tbloomberg\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tbloomberg\x12.\n\x03\x63ik\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03\x63ik\x12<\n\ncomponents\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\ncomponents\x12\x38\n\x08\x63ontract\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63ontract\x12\x41\n\rbase_currency\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0c\x62\x61seCurrency\x12\x43\n\x0equote_currency\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rquoteCurrency\x12\x32\n\x05\x63usip\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x63usip\x12>\n\x0b\x64\x65scription\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0b\x64\x65scription\x12\x38\n\x08\x65xchange\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x65xchange\x12\x30\n\x04\x66igi\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04\x66igi\x12\x32\n\x05\x66igic\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05\x66igic\x12\x32\n\x05index\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05index\x12\x30\n\x04isin\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04isin\x12\x34\n\x06markit\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06markit\x12>\n\x0bmorningstar\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bmorningstar\x12\x30\n\x04name\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04name\x12:\n\toperating\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\toperating\x12\x36\n\x07primary\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07primary\x12\x36\n\x07reuters\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x07reuters\x12\x34\n\x06sector\x18\x17 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06sector\x12\x32\n\x05sedol\x18\x18 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sedol\x12\x34\n\x06ticker\x18\x19 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06ticker\x12<\n\nunderlying\x18\x1a \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nunderlying\x12\x44\n\x0e\x63lassification\x18\x1b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63lassification\x12Z\n\x08maturity\x18\x1c \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeR\x08maturity\x12h\n\x0e\x63\x61pitalization\x18\x1d \x01(\x0b\x32@.systemathics.apis.services.static_data.v1.StaticDataDoubleRangeR\x0e\x63\x61pitalization\x12V\n\x06\x65xpiry\x18\x1e \x01(\x0b\x32>.systemathics.apis.services.static_data.v1.StaticDataDateRangeR\x06\x65xpiry\x12V\n\x0boption_type\x18\x1f \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18  \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x12P\n\tbond_type\x18! \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.BondTypeR\x08\x62ondType\x12:\n\tseniority\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tseniority\x12\x34\n\x06issuer\x18# \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x06issuer\"\x8b\x01\n\x13StaticDataDateRange\x12.\n\tless_than\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x08lessThan\x12\x44\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x11.google.type.DateR\x12greaterOrEqualThan\"\xa3\x01\n\x15StaticDataDoubleRange\x12\x39\n\tless_than\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x08lessThan\x12O\n\x15greater_or_equal_than\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x12greaterOrEqualThan\"\xe1\x05\n\x12StaticDataResponse\x12Q\n\x06\x66uture\x18\x01 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.FutureResponseR\x06\x66uture\x12Q\n\x06\x65quity\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.EquityResponseR\x06\x65quity\x12H\n\x03\x65tf\x18\x03 \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EtfResponseR\x03\x65tf\x12N\n\x05index\x18\x04 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.IndexResponseR\x05index\x12Q\n\x06\x63rypto\x18\x05 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.CryptoResponseR\x06\x63rypto\x12N\n\x05\x66orex\x18\x06 \x01(\x0b\x32\x38.systemathics.apis.services.static_data.v1.ForexResponseR\x05\x66orex\x12Q\n\x06option\x18\x07 \x01(\x0b\x32\x39.systemathics.apis.services.static_data.v1.OptionResponseR\x06option\x12K\n\x04\x62ond\x18\x08 \x01(\x0b\x32\x37.systemathics.apis.services.static_data.v1.BondResponseR\x04\x62ond\x12H\n\x03\x63\x64s\x18\t \x01(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CdsResponseR\x03\x63\x64s\"}\n\x0c\x42ondResponse\x12L\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x34.systemathics.apis.services.static_data.v1.BondEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x43\x64sResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.CdsEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x43ryptoResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.CryptoEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x45quityResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"{\n\x0b\x45tfResponse\x12K\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rForexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.ForexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0e\x46utureResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x7f\n\rIndexResponse\x12M\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\x81\x01\n\x0eOptionResponse\x12N\n\x06\x61ssets\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.OptionEntryR\x06\x61ssets\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\"\xa0\r\n\x0b\x45quityEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12]\n\x07sectors\x18\" \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntryR\x07sectors\x12\x44\n\x0e\x63\x61pitalization\x18# \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x12]\n\x07holders\x18( \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.HoldersEntryR\x07holders\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cHoldersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xe3\x0c\n\x08\x45tfEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12Z\n\x07mapping\x18\x16 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x10\n\x03\x63ik\x18! \x01(\tR\x03\x63ik\x12Z\n\x07sectors\x18\" \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntryR\x07sectors\x12\x44\n\x0e\x63\x61pitalization\x18# \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12\x18\n\x07\x61\x64\x64ress\x18$ \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05phone\x18% \x01(\tR\x05phone\x12\x14\n\x05\x65mail\x18& \x01(\tR\x05\x65mail\x12\x10\n\x03url\x18\' \x01(\tR\x03url\x12\x16\n\x06issuer\x18( \x01(\tR\x06issuer\x12\x1b\n\tfund_type\x18) \x01(\tR\x08\x66undType\x12\x30\n\nissue_date\x18* \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a:\n\x0cSectorsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x84\x0c\n\x0b\x46utureEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x1a\n\x08\x63ontract\x18\" \x01(\tR\x08\x63ontract\x12`\n\x08\x63\x61tegory\x18# \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntryR\x08\x63\x61tegory\x12\x14\n\x05\x63hain\x18$ \x01(\tR\x05\x63hain\x12-\n\x08maturity\x18% \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12\x14\n\x05month\x18& \x01(\tR\x05month\x12\x12\n\x04year\x18\' \x01(\x05R\x04year\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a;\n\rCategoryEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe9\x0c\n\nIndexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1a\n\x08\x63\x61tegory\x18! \x01(\tR\x08\x63\x61tegory\x12 \n\x0bmethodology\x18\" \x01(\tR\x0bmethodology\x12\x16\n\x06issuer\x18# \x01(\tR\x06issuer\x12\x30\n\nissue_date\x18$ \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12V\n\tfrequency\x18% \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x65\n\ncomponents\x18& \x03(\x0b\x32\x45.systemathics.apis.services.static_data.v1.IndexEntry.ComponentsEntryR\ncomponents\x12)\n\x10\x63omponents_count\x18\' \x01(\x03R\x0f\x63omponentsCount\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a=\n\x0f\x43omponentsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xf1\x0b\n\x0b\x43ryptoEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x07 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.CryptoEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x12\x1c\n\tconsensus\x18\" \x03(\tR\tconsensus\x12\x30\n\nissue_date\x18# \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12\x44\n\x0e\x63\x61pitalization\x18$ \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x0e\x63\x61pitalization\x12-\n\x12\x63irculating_supply\x18% \x01(\x05R\x11\x63irculatingSupply\x12\x1d\n\nmax_supply\x18& \x01(\x05R\tmaxSupply\x12!\n\x0ctotal_supply\x18\' \x01(\x05R\x0btotalSupply\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xe8\t\n\nForexEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12#\n\rbase_currency\x18\x07 \x01(\tR\x0c\x62\x61seCurrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12\\\n\x07mapping\x18\x16 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.ForexEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12%\n\x0equote_currency\x18! \x01(\tR\rquoteCurrency\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xd3\x0b\n\x0bOptionEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12]\n\x07mapping\x18\x16 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.OptionEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12\x16\n\x06strike\x18\" \x01(\x01R\x06strike\x12)\n\x06\x65xpiry\x18# \x01(\x0b\x32\x11.google.type.DateR\x06\x65xpiry\x12V\n\x0boption_type\x18$ \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.OptionTypeR\noptionType\x12\\\n\rexercise_type\x18% \x01(\x0e\x32\x37.systemathics.apis.services.static_data.v1.ExerciseTypeR\x0c\x65xerciseType\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xec\r\n\tBondEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12[\n\x07mapping\x18\x16 \x03(\x0b\x32\x41.systemathics.apis.services.static_data.v1.BondEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x16\n\x06issuer\x18! \x01(\tR\x06issuer\x12-\n\x08maturity\x18\" \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12P\n\tbond_type\x18# \x01(\x0e\x32\x33.systemathics.apis.services.static_data.v1.BondTypeR\x08\x62ondType\x12V\n\tfrequency\x18$ \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12V\n\x0b\x63oupon_type\x18% \x01(\x0e\x32\x35.systemathics.apis.services.static_data.v1.CouponTypeR\ncouponType\x12\x1f\n\x0b\x63oupon_rate\x18& \x01(\x01R\ncouponRate\x12\x30\n\nissue_date\x18\' \x01(\x0b\x32\x11.google.type.DateR\tissueDate\x12\"\n\x0c\x64\x65nomination\x18( \x01(\x01R\x0c\x64\x65nomination\x12\x1f\n\x0bissue_price\x18) \x01(\x01R\nissuePrice\x12\x14\n\x05total\x18* \x01(\x01R\x05total\x12\x1f\n\x0b\x66\x61\x63\x65_amount\x18+ \x01(\x01R\nfaceAmount\x12\x1c\n\tseniority\x18, \x01(\tR\tseniority\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x0b\n\x08\x43\x64sEntry\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12\x18\n\x07primary\x18\x04 \x01(\tR\x07primary\x12\x1c\n\toperating\x18\x05 \x01(\tR\toperating\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x1a\n\x08\x63urrency\x18\x07 \x01(\tR\x08\x63urrency\x12\x18\n\x07\x63ountry\x18\x08 \x01(\tR\x07\x63ountry\x12Y\n\x0etick_size_rule\x18\t \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.TickSizeR\x0ctickSizeRule\x12\x14\n\x05index\x18\n \x03(\tR\x05index\x12\x1a\n\x08\x63\x61lendar\x18\x0b \x01(\tR\x08\x63\x61lendar\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12-\n\x04open\x18\r \x01(\x0b\x32\x19.google.protobuf.DurationR\x04open\x12/\n\x05\x63lose\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationR\x05\x63lose\x12\x1b\n\ttime_zone\x18\x0f \x01(\tR\x08timeZone\x12\x19\n\x08lot_size\x18\x10 \x01(\x03R\x07lotSize\x12\x1f\n\x0bpoint_value\x18\x11 \x01(\x01R\npointValue\x12\x32\n\x05price\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueR\x05price\x12\x33\n\x06volume\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x06volume\x12%\n\x04time\x18\x14 \x01(\x0b\x32\x11.google.type.DateR\x04time\x12\x18\n\x07sources\x18\x15 \x01(\x05R\x07sources\x12Z\n\x07mapping\x18\x16 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.CdsEntry.MappingEntryR\x07mapping\x12\x1c\n\tbloomberg\x18\x17 \x01(\tR\tbloomberg\x12\x18\n\x07reuters\x18\x18 \x01(\tR\x07reuters\x12 \n\x0bmorningstar\x18\x19 \x01(\tR\x0bmorningstar\x12\x16\n\x06markit\x18\x1a \x01(\tR\x06markit\x12\x12\n\x04\x66igi\x18\x1b \x01(\tR\x04\x66igi\x12\x14\n\x05\x66igic\x18\x1c \x01(\tR\x05\x66igic\x12\x12\n\x04isin\x18\x1d \x01(\tR\x04isin\x12\x14\n\x05\x63usip\x18\x1e \x01(\tR\x05\x63usip\x12\x14\n\x05sedol\x18\x1f \x01(\tR\x05sedol\x12&\n\x0e\x63lassification\x18  \x01(\tR\x0e\x63lassification\x12\x1e\n\nunderlying\x18! \x01(\tR\nunderlying\x12-\n\x08maturity\x18\" \x01(\x0b\x32\x11.google.type.DateR\x08maturity\x12V\n\tfrequency\x18# \x01(\x0e\x32\x38.systemathics.apis.services.static_data.v1.FrequencyTypeR\tfrequency\x12\x14\n\x05tenor\x18$ \x01(\tR\x05tenor\x12\x1a\n\x08recovery\x18% \x01(\x01R\x08recovery\x1a:\n\x0cMappingEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"4\n\x08TickSize\x12\x14\n\x05price\x18\x01 \x01(\x01R\x05price\x12\x12\n\x04tick\x18\x02 \x01(\x01R\x04tick*\x80\x02\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x12\x15\n\x11\x41SSET_TYPE_CRYPTO\x10\x06\x12\x14\n\x10\x41SSET_TYPE_FOREX\x10\x07\x12\x15\n\x11\x41SSET_TYPE_OPTION\x10\x08\x12\x13\n\x0f\x41SSET_TYPE_BOND\x10\t\x12\x12\n\x0e\x41SSET_TYPE_CDS\x10\n*\x86\x02\n\rFrequencyType\x12\x1e\n\x1a\x46REQUENCY_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x46REQUENCY_TYPE_NONE\x10\x01\x12\x16\n\x12\x46REQUENCY_TYPE_DAY\x10\x02\x12\x17\n\x13\x46REQUENCY_TYPE_WEEK\x10\x03\x12\x18\n\x14\x46REQUENCY_TYPE_MONTH\x10\x04\x12\x1a\n\x16\x46REQUENCY_TYPE_QUARTER\x10\x05\x12\x1d\n\x19\x46REQUENCY_TYPE_SEMIANNUAL\x10\x06\x12\x19\n\x15\x46REQUENCY_TYPE_ANNUAL\x10\x07\x12\x1b\n\x17\x46REQUENCY_TYPE_BIANNUAL\x10\x08*T\n\nOptionType\x12\x1b\n\x17OPTION_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10OPTION_TYPE_CALL\x10\x01\x12\x13\n\x0fOPTION_TYPE_PUT\x10\x02*\x81\x01\n\x0c\x45xerciseType\x12\x1d\n\x19\x45XERCISE_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45XERCISE_TYPE_AMERICAN\x10\x01\x12\x1a\n\x16\x45XERCISE_TYPE_EUROPEAN\x10\x02\x12\x1a\n\x16\x45XERCISE_TYPE_BERMUDAN\x10\x03*m\n\x08\x42ondType\x12\x19\n\x15\x42OND_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14\x42OND_TYPE_GOVERNMENT\x10\x01\x12\x17\n\x13\x42OND_TYPE_CORPORATE\x10\x02\x12\x13\n\x0f\x42OND_TYPE_OTHER\x10\x03*p\n\nCouponType\x12\x1b\n\x17\x43OUPON_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43OUPON_TYPE_NONE\x10\x01\x12\x15\n\x11\x43OUPON_TYPE_FIXED\x10\x02\x12\x18\n\x14\x43OUPON_TYPE_FLOATING\x10\x03\x32\xb7\x01\n\x11StaticDataService\x12\xa1\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/staticdataB\x85\x02\n-com.systemathics.apis.services.static_data.v1B\x0fStaticDataProtoP\x01\xa2\x02\x04SASS\xaa\x02(Systemathics.Apis.Services.StaticData.V1\xca\x02(Systemathics\\Apis\\Services\\StaticData\\V1\xe2\x02\x34Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\xea\x02,Systemathics::Apis::Services::StaticData::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.static_data.v1.static_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.systemathics.apis.services.static_data.v1B\017StaticDataProtoP\001\242\002\004SASS\252\002(Systemathics.Apis.Services.StaticData.V1\312\002(Systemathics\\Apis\\Services\\StaticData\\V1\342\0024Systemathics\\Apis\\Services\\StaticData\\V1\\GPBMetadata\352\002,Systemathics::Apis::Services::StaticData::V1'
  _globals['_EQUITYENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_SECTORSENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_EQUITYENTRY_HOLDERSENTRY']._loaded_options = None
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_options = b'8\001'
  _globals['_ETFENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_ETFENTRY_SECTORSENTRY']._loaded_options = None
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FUTUREENTRY_CATEGORYENTRY']._loaded_options = None
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_options = b'8\001'
  _globals['_INDEXENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_INDEXENTRY_COMPONENTSENTRY']._loaded_options = None
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_options = b'8\001'
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_FOREXENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_OPTIONENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_BONDENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_CDSENTRY_MAPPINGENTRY']._loaded_options = None
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_options = b'8\001'
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._loaded_options = None
  _globals['_STATICDATASERVICE'].methods_by_name['StaticData']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/staticdata'
  _globals['_ASSETTYPE']._serialized_start=18788
  _globals['_ASSETTYPE']._serialized_end=19044
  _globals['_FREQUENCYTYPE']._serialized_start=19047
  _globals['_FREQUENCYTYPE']._serialized_end=19309
  _globals['_OPTIONTYPE']._serialized_start=19311
  _globals['_OPTIONTYPE']._serialized_end=19395
  _globals['_EXERCISETYPE']._serialized_start=19398
  _globals['_EXERCISETYPE']._serialized_end=19527
  _globals['_BONDTYPE']._serialized_start=19529
  _globals['_BONDTYPE']._serialized_end=19638
  _globals['_COUPONTYPE']._serialized_start=19640
  _globals['_COUPONTYPE']._serialized_end=19752
  _globals['_STATICDATAREQUEST']._serialized_start=276
  _globals['_STATICDATAREQUEST']._serialized_end=2520
  _globals['_STATICDATADATERANGE']._serialized_start=2523
  _globals['_STATICDATADATERANGE']._serialized_end=2662
  _globals['_STATICDATADOUBLERANGE']._serialized_start=2665
  _globals['_STATICDATADOUBLERANGE']._serialized_end=2828
  _globals['_STATICDATARESPONSE']._serialized_start=2831
  _globals['_STATICDATARESPONSE']._serialized_end=3568
  _globals['_BONDRESPONSE']._serialized_start=3570
  _globals['_BONDRESPONSE']._serialized_end=3695
  _globals['_CDSRESPONSE']._serialized_start=3697
  _globals['_CDSRESPONSE']._serialized_end=3820
  _globals['_CRYPTORESPONSE']._serialized_start=3823
  _globals['_CRYPTORESPONSE']._serialized_end=3952
  _globals['_EQUITYRESPONSE']._serialized_start=3955
  _globals['_EQUITYRESPONSE']._serialized_end=4084
  _globals['_ETFRESPONSE']._serialized_start=4086
  _globals['_ETFRESPONSE']._serialized_end=4209
  _globals['_FOREXRESPONSE']._serialized_start=4211
  _globals['_FOREXRESPONSE']._serialized_end=4338
  _globals['_FUTURERESPONSE']._serialized_start=4341
  _globals['_FUTURERESPONSE']._serialized_end=4470
  _globals['_INDEXRESPONSE']._serialized_start=4472
  _globals['_INDEXRESPONSE']._serialized_end=4599
  _globals['_OPTIONRESPONSE']._serialized_start=4602
  _globals['_OPTIONRESPONSE']._serialized_end=4731
  _globals['_EQUITYENTRY']._serialized_start=4734
  _globals['_EQUITYENTRY']._serialized_end=6430
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_EQUITYENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_start=6312
  _globals['_EQUITYENTRY_SECTORSENTRY']._serialized_end=6370
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_start=6372
  _globals['_EQUITYENTRY_HOLDERSENTRY']._serialized_end=6430
  _globals['_ETFENTRY']._serialized_start=6433
  _globals['_ETFENTRY']._serialized_end=8068
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_ETFENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_start=6312
  _globals['_ETFENTRY_SECTORSENTRY']._serialized_end=6370
  _globals['_FUTUREENTRY']._serialized_start=8071
  _globals['_FUTUREENTRY']._serialized_end=9611
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_FUTUREENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_start=9552
  _globals['_FUTUREENTRY_CATEGORYENTRY']._serialized_end=9611
  _globals['_INDEXENTRY']._serialized_start=9614
  _globals['_INDEXENTRY']._serialized_end=11255
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_INDEXENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_start=11194
  _globals['_INDEXENTRY_COMPONENTSENTRY']._serialized_end=11255
  _globals['_CRYPTOENTRY']._serialized_start=11258
  _globals['_CRYPTOENTRY']._serialized_end=12779
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_CRYPTOENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_FOREXENTRY']._serialized_start=12782
  _globals['_FOREXENTRY']._serialized_end=14038
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_FOREXENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_OPTIONENTRY']._serialized_start=14041
  _globals['_OPTIONENTRY']._serialized_end=15532
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_OPTIONENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_BONDENTRY']._serialized_start=15535
  _globals['_BONDENTRY']._serialized_end=17307
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_BONDENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_CDSENTRY']._serialized_start=17310
  _globals['_CDSENTRY']._serialized_end=18731
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_start=6252
  _globals['_CDSENTRY_MAPPINGENTRY']._serialized_end=6310
  _globals['_TICKSIZE']._serialized_start=18733
  _globals['_TICKSIZE']._serialized_end=18785
  _globals['_STATICDATASERVICE']._serialized_start=19755
  _globals['_STATICDATASERVICE']._serialized_end=19938
# @@protoc_insertion_point(module_scope)
